/*******************************************************************************
 * Copyright (c) 2021, Bayerische Motoren Werke Aktiengesellschaft (BMW AG)
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *******************************************************************************/

//-----------------------------------------------------------------------------
/** @file  simulation_time.h */
//-----------------------------------------------------------------------------

#ifndef MANTLEAPI_COMMON_SIMULATION_TIME_H
#define MANTLEAPI_COMMON_SIMULATION_TIME_H

#include <chrono>

namespace mantle_api
{
using SimulationTime = std::chrono::duration<std::int64_t, std::milli>;

/// @brief Converts input in [s] to @ref SimulationTime.
/// @tparam T Input type, eg. `double`.
/// @param duration Input value
/// @return Duration representing the given input in units of @ref SimulationTime.
template <typename T>
inline SimulationTime SecondsToSimulationTime(T duration)
{
    return std::chrono::duration_cast<SimulationTime>(std::chrono::duration<T>{duration});
}

/// @brief Converts input @ref SimulationTime to [s].
/// @param time Simulation time
/// @return Duration ins seconds representing the passed in @ref SimulationTime.
inline double SimulationTimeToSeconds(const SimulationTime& time)
{
    return static_cast<double>(time.count()) / 1000.0;
}
  
}  // namespace mantle_api

#endif  // MANTLEAPI_COMMON_SIMULATION_TIME_H
